summaryrefslogtreecommitdiffstats
path: root/tools
diff options
context:
space:
mode:
Diffstat (limited to 'tools')
-rw-r--r--tools/h5repack/h5repack_copy.c2
-rw-r--r--tools/h5stat/h5stat_gentest.c2
-rw-r--r--tools/misc/h5mkgrp.c4
3 files changed, 4 insertions, 4 deletions
diff --git a/tools/h5repack/h5repack_copy.c b/tools/h5repack/h5repack_copy.c
index 2504a96..870bcaa 100644
--- a/tools/h5repack/h5repack_copy.c
+++ b/tools/h5repack/h5repack_copy.c
@@ -176,7 +176,7 @@ int copy_objects(const char* fnamein,
goto out;
} /* end if */
- if(H5Pset_latest_format(fapl, TRUE) < 0) {
+ if(H5Pset_format_bounds(fapl, H5F_FORMAT_LATEST, H5F_FORMAT_LATEST) < 0) {
error_msg(progname, "Could not set property for using latest version of the format\n");
goto out;
} /* end if */
diff --git a/tools/h5stat/h5stat_gentest.c b/tools/h5stat/h5stat_gentest.c
index 22396b6..bf10632 100644
--- a/tools/h5stat/h5stat_gentest.c
+++ b/tools/h5stat/h5stat_gentest.c
@@ -46,7 +46,7 @@ static void gen_file(void)
char attrname[30];
fapl = H5Pcreate(H5P_FILE_ACCESS);
- ret = H5Pset_latest_format(fapl, 1);
+ ret = H5Pset_format_bounds(fapl, H5F_FORMAT_LATEST, H5F_FORMAT_LATEST);
/* Create dataset */
file = H5Fcreate(FILE, H5F_ACC_TRUNC, H5P_DEFAULT, fapl);
diff --git a/tools/misc/h5mkgrp.c b/tools/misc/h5mkgrp.c
index c39d07b..6de00f7 100644
--- a/tools/misc/h5mkgrp.c
+++ b/tools/misc/h5mkgrp.c
@@ -233,8 +233,8 @@ main(int argc, const char *argv[])
/* Check for creating groups with new format version */
if(params.latest) {
- /* Set the "use the latest version of the format flag */
- if(H5Pset_latest_format(fapl_id, TRUE) < 0) {
+ /* Set the "use the latest version of the format" bounds */
+ if(H5Pset_format_bounds(fapl_id, H5F_FORMAT_LATEST, H5F_FORMAT_LATEST) < 0) {
error_msg(progname, "Could not set property for using latest version of the format\n");
leave(EXIT_FAILURE);
} /* end if */